#:coding=utf-8:
import os

from django.http import HttpRequest, HttpResponse
from django.test import TestCase as DjangoTestCase
from django.conf import settings

from beproud.django.commons.views.decorators import * 
from beproud.django.commons.views import Views

class TestViews(Views):
    def test(self, request):
        return HttpResponse("OK")

    def get_urls(self):
        from django.conf.urls.defaults import url,patterns
        urls = super(TestViews, self).get_urls()
        my_urls = patterns('',
            url(
                r'^test$',
                self.test,
                name='testview_test',
            ),
        )
        return my_urls + urls

class ClassesTestCase(DjangoTestCase):
    def test_simple(self):
        response = self.client.get("/test")
        self.assertEquals(response.status_code, 200)
        self.assertEquals(response.content, "OK")

@render_to("view_tests/render_to.html")
def myview(request):
    return {"my_value": "MY VALUE"}

@render_to("view_tests/render_to.html")
def myview2(request):
    return HttpResponse("Error!") 

class RenderToTestCase(DjangoTestCase):
    def setUp(self):
        self.template_dirs = settings.TEMPLATE_DIRS

    def tearDown(self):
        settings.TEMPLATE_DIRS = self.template_dirs
    
    def test_render_to(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        resp = myview(HttpRequest())
        self.assertEquals(resp.content, '<html><body>MY VALUE</body></html>\n')

    def test_render_to_httpresponse(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        resp = myview2(HttpRequest())
        self.assertEquals(resp.content, 'Error!')

@ajax_request
def my_ajax_view(request):
    return {'my_value': 'MY VALUE'}

@ajax_request
def my_ajax_view2(request):
    return HttpResponse("Error!") 

class AjaxResponseTestCase(DjangoTestCase):
    def test_ajax_view(self):
        resp = my_ajax_view(HttpRequest())
        self.assertEquals(resp["content-type"], 'application/json')
        self.assertEquals(resp.content, '{"my_value": "MY VALUE"}')

    def test_ajax_view_httpresponse(self):
        resp = my_ajax_view2(HttpRequest())
        self.assertEquals(resp["content-type"], 'text/html; charset=utf-8')
        self.assertEquals(resp.content, 'Error!')

def my_json_view(request):
    return JSONResponse({"msg":"テスト"}, status=400)

class JSONResponseTestCase(DjangoTestCase):
    def test_json_view(self):
        resp = my_json_view(HttpRequest())
        self.assertEquals(resp["content-type"], 'application/json')
        self.assertEquals(resp.content, r'{"msg": "\u30c6\u30b9\u30c8"}')
        self.assertEquals(resp.status_code, 400)



# vim:fileencoding=utf-8

from django.utils.datastructures import SortedDict

__all__ = (
    'Choices',
    'with_empty_tuple',
)

class Choices(object):
    """
    Easy declarative "choices" tool::
    
        >>> STATUSES = Choices(
        ...     (1, 'live', 'Live'),
        ...     (2, 'draft', 'Draft'),
        ...     (3, 'hidden', 'Not Live'),
        ... )
        
        # Acts like a choices list:
        >>> list(STATUSES)
        [(1, 'Live'), (2, 'Draft')]
        
        # Easily convert from code to verbose:
        >>> STATUSES.verbose(1)
        'Live'

        >>> STATUS.prop(1)
        'live'
        
        # ... and vice versa:
        >>> STATUSES.code("draft")
        2

        status = models.SmallIntegerField(choices=STATUSES,
        ...                                       default=STATUSES["live"])
        
    """
    def __init__(self, *args, **kwargs):
        self.code_map = SortedDict()
        self.prop_map = SortedDict() 
        self.reverse_map = {}
        for code, prop, verbose in args:
            self.code_map[code] = verbose
            self.prop_map[code] = prop
            self.reverse_map[prop] = code
            
    def __iter__(self):
        return self.code_map.iteritems()
                
    def __len__(self):
        return len(self.code_map)

    def __getitem__(self, prop):
        return self.code(prop)

    def __contains__(self, prop):
        return prop in self.reverse_map 

    def code(self, prop):
        """
        Return the code version of the verbose name.
        """
        return self.reverse_map[prop]

    def prop(self, code):
        return self.prop_map[code]
        
    def verbose(self, code):
        """
        Return the verbose name given the code.
        """
        return self.code_map[code]
    
    def __repr__(self):
        return repr(tuple(self.code_map.items()))

def with_empty_tuple(tp, add=('', '--')):
    l = list(tp)
    l.insert(0, add)
    return tuple(l)



#:coding=utf-8:

from django.db import models
from datetime import datetime

__all__ = (
    'DatedModelManager',
    'DatedModel',
    'BaseManager',
    'BaseModel',
)

class DatedModelManager(models.Manager):
    def recently_updated(self):
        return self.order_by('-utime')

class DatedModel(models.Model):
    """
    日付が付けたモデル
    """
    ctime = models.DateTimeField(u'作成日時', default=datetime.now, db_index=True)
    utime = models.DateTimeField(u'更新日時', auto_now=True, db_index=True)

    objects = DatedModelManager()

    class Meta:
        abstract = True
        ordering = ['-ctime']

class BaseManager(DatedModelManager):
    def be(self):
        """
        削除されてないBaseModelオブジェクトを取得
        """
        return self.filter(del_flg=False)

class BaseModel(DatedModel):
    """
    BaseModelの実装
    
    使い方:
    from django.db import models
    from commons.models import BaseModel

    class MyModel(BaseModel):
        myfield = models.BooleanField()

    MyModel.existing.filter(myfield=True)
    """
    del_flg = models.BooleanField(u'削除フラグ', default=False)

    objects = BaseManager()

    def remove(self):
        self.del_flg = True
        self.save()

    def unremove(self):
        self.del_flg = False 
        self.save()

    class Meta:
        abstract = True
        ordering = ['-ctime']



# vim:fileencoding=utf-8
import os
import re
try:
    from cStringIO import StringIO
except ImportError:
    from StringIO import StringIO

from PIL import Image

def valid_image(image):
    try:
        Image.open(image)
    except IOError:
        return False
    image.seek(0)
    return True

def optimize_resize(image,size):
    frm = image.format
    w, h = image.size
    box = () 
    if w < h :
        s = (h - w) / 2
        box = (0, s, w, s + w)
    else :
        s = (w-h) / 2
        box = (s, 0, s + h, h)
    image = image.crop(box)
    image = image.resize(size, Image.ANTIALIAS)
    return image

def make_content_image_file(image, size=None):
    """ """
    from django.core.files.base import ContentFile
    format = image.format
    if size:
        image = image.resize(size, Image.ANTIALIAS);
    sio = StringIO()
    image.save(sio, format)
    return ContentFile(sio.getvalue());

def get_image_size(fileobj, limit=None):
    image = Image.open(fileobj)
    w, h = image.size
    if limit:
        if max(w, h) > limit:
            if w > h:
                h = h * limit / w
                w = limit
            else:
                w = w * limit / h
                h = limit
    return w, h



# vim:fileencoding=utf-8

from django.utils.encoding import force_unicode
from django.utils import simplejson

from beproud.utils.javascript import escapejs_json, SafeJSONEncoder

__all__ = (
    'DjangoJSONEncoder',
)

class DjangoJSONEncoder(SafeJSONEncoder):
    def default(self, obj):
        try:
            #datetime対応
            return super(DjangoJSONEncoder, self).default(obj)
        except TypeError:
            # lazy翻訳オブジェクトなどの対応
            from django.utils.functional import Promise
            if isinstance(obj, Promise):
                return escapejs_json(force_unicode(obj))
            else:
                raise



#:coding=utf-8:

from beproud.django.commons.http import JSONResponse

__all__ = (
        'get_object_or_None',
        'make_simple_response',
        'make_simple_response400',
        'make_simple_response401',
        'make_simple_response403',
        'make_simple_response500',
)

def get_object_or_None(klass, *args, **kwargs):
    """
    Uses get() to return an object or None if the object does not exist.

    klass may be a Model, Manager, or QuerySet object. All other passed
    arguments and keyword arguments are used in the get() query.

    Note: Like with get(), an MultipleObjectsReturned will be raised if more than one
    object is found.
    """
    from django.shortcuts import _get_queryset
    queryset = _get_queryset(klass)
    try:
        return queryset.get(*args, **kwargs)
    except queryset.model.DoesNotExist:
        return None

def make_simple_response(msg=u'処理が成功しました', extra_context=None, status=200, content_type='application/json'):
    obj = {'msg': msg}
    if extra_context:
        obj.update(extra_context)
    return JSONResponse(obj, status=status, content_type=content_type)

def make_simple_response400(msg=u'パラメータが不正です'):
    return make_simple_response(msg, status=400)

def make_simple_response401(msg=u'ログインしてください'):
    return make_simple_response(msg, status=401)

def make_simple_response403(msg=u'不正な処理です'):
    return make_simple_response(msg, status=403)

def make_simple_response500(msg=u'サーバー側で問題が発生しています。しばらく経ってからもう一度試してみてください'):
    return make_simple_response(msg, status=500)



#:coding=utf-8:

from django.test import TestCase as DjangoTestCase
from django.utils import simplejson

from beproud.django.commons.utils.javascript import DjangoJSONEncoder

def dump_json(data):
    return simplejson.dumps(data, cls=DjangoJSONEncoder)

class DjangoJSONEncoderTestCase(DjangoTestCase):

    def test_escape(self):
        self.assertEqual(dump_json(u"<テスト>"), u'"\\u003c\\u30c6\\u30b9\\u30c8\\u003e"')
        self.assertEqual(dump_json(u"Q&A"), u'"Q\\u0026A"')
        self.assertEqual(dump_json(u"データ"), u'"\\u30c7\\u30fc\\u30bf"')

    def test_lazy(self):
        # lazyオブジェクトテスト
        from django.utils.functional import lazy
        def test_func():
            return "value"
        lazy_test_func = lazy(test_func, str)
        val = lazy_test_func()
        self.assertEqual(dump_json(val), '"value"')



#:coding=utf-8:

import base64
import warnings

try:
	import cPickle as pickle
except ImportError:
	import pickle

from django import VERSION as DJANGO_VERSION
from django.core import exceptions
from django.utils.translation import ugettext_lazy as _
from django.utils import simplejson
from django.db import load_backend
from django.db import connection
from django.db import models
from django.conf import settings

from beproud.django.commons.forms import JSONField as JSONFormField
from beproud.django.commons.forms.widgets import JSONWidget
from beproud.django.commons.utils.javascript import DjangoJSONEncoder

__all__ = (
    'BigIntegerField',
    'PositiveBigIntegerField',
    'BigAutoField',
    'PickledObjectField',
    'JSONField',
)

if DJANGO_VERSION > (1,2):
    from django.db.models import BigIntegerField

    class BigAutoField(models.AutoField):
        description = _("Big (8 byte) integer")
     
        CREATION_DATA = {
            'django.db.backends.mysql': "bigint AUTO_INCREMENT",
            'django.db.backends.oracle': "NUMBER(19)",
            'django.db.backends.postgresql': "bigserial",
            'django.db.backends.postgresql_psycopg2': "bigserial",
            'django.db.backends.sqlite3': "integer", # Not a bigint!!!
        }

        def db_type(self, connection):
            try:
                for backend, db_type in self.CREATION_DATA.items():
                    try:
                        module = load_backend(backend)
                        if isinstance(connection, getattr(module, 'DatabaseWrapper')):
                            return db_type
                    except (ImportError, exceptions.ImproperlyConfigured):
                        pass
            except (KeyError, AttributeError):
                pass
            raise exceptions.ImproperlyConfigured("BigAutoField does not support the %s database backend" % connection.settings_dict["ENGINE"])

        def get_internal_type(self):
            return "BigAutoField"
        
        def get_prep_value(self, value):
            if value is None:
                return None
            return long(value)
        
        def to_python(self, value):
            if value is None:
                return value
            try:
                return long(value)
            except (TypeError, ValueError):
                raise exceptions.ValidationError(self.error_messages['invalid'])

    def fk_db_type(self, connection):
        # The database column type of a ForeignKey is the column type
        # of the field to which it points. An exception is if the ForeignKey
        # points to an AutoField/PositiveIntegerField/PositiveSmallIntegerField,
        # in which case the column type is simply that of an IntegerField.
        # If the database needs similar types for key fields however, the only
        # thing we can do is making AutoField an IntegerField.
        rel_field = self.rel.get_related_field()

        if (isinstance(rel_field, BigAutoField) or
                (not connection.features.related_fields_match_type and
                isinstance(rel_field, PositiveBigIntegerField))):
            return BigIntegerField().db_type(connection=connection)

        if (isinstance(rel_field, models.AutoField) or
                (not connection.features.related_fields_match_type and
                isinstance(rel_field, (models.PositiveIntegerField,
                                       models.PositiveSmallIntegerField)))):
            return models.IntegerField().db_type(connection=connection)
        return rel_field.db_type(connection=connection)

    # ForeignKey monkey-patch to support BigAutoId
    models.ForeignKey.db_type = fk_db_type

else:
    """
    For Django 1.1
    """

    class BigIntegerField(models.IntegerField):
        empty_strings_allowed = False
        description = _("Big (8 byte) integer")
        MAX_BIGINT = 9223372036854775807
        def get_internal_type(self):
            return "BigIntegerField"

        def formfield(self, **kwargs):
            defaults = {'min_value': -BigIntegerField.MAX_BIGINT - 1,
                        'max_value': BigIntegerField.MAX_BIGINT}
            defaults.update(kwargs)
            return super(BigIntegerField, self).formfield(**defaults)

        def db_type(self):
            try:
                module = load_backend("oracle")
                if isinstance(connection, getattr(module, 'DatabaseWrapper')):
                    return 'NUMBER(19)'
            except (KeyError, AttributeError, ImportError, exceptions.ImproperlyConfigured):
                pass
            return 'bigint'

    class BigAutoField(models.AutoField):
        
        CREATION_DATA = {
            'mysql': "bigint AUTO_INCREMENT",
            'oracle': "NUMBER(19)",
            'postgresql': "bigserial",
            'postgresql_psycopg2': "bigserial",
            'sqlite3': "integer", # Not a bigint!!!
        }

        def db_type(self):
            try:
                for backend, db_type in self.CREATION_DATA.items():
                    try:
                        module = load_backend(backend)
                        if isinstance(connection, getattr(module, 'DatabaseWrapper')):
                            return db_type
                    except (ImportError, exceptions.ImproperlyConfigured):
                        pass
            except (KeyError, AttributeError):
                pass
            raise exceptions.ImproperlyConfigured("BigAutoField does not support the %s database backend" % settings.DATABASE_ENGINE)

        def get_internal_type(self):
            return "BigAutoField"
        
        def to_python(self, value):
            if value is None:
                return value
            try:
                return long(value)
            except (TypeError, ValueError):
                raise exceptions.ValidationError(
                    _("This value must be a long integer."))

    def fk_db_type(self):
        # The database column type of a ForeignKey is the column type
        # of the field to which it points. An exception is if the ForeignKey
        # points to an AutoField/PositiveIntegerField/PositiveSmallIntegerField,
        # in which case the column type is simply that of an IntegerField.
        # If the database needs similar types for key fields however, the only
        # thing we can do is making AutoField an IntegerField.
        rel_field = self.rel.get_related_field()

        if (isinstance(rel_field, BigAutoField) or
                (not connection.features.related_fields_match_type and
                isinstance(rel_field, PositiveBigIntegerField))):
            return BigIntegerField().db_type()

        if (isinstance(rel_field, models.AutoField) or
                (not connection.features.related_fields_match_type and
                isinstance(rel_field, (models.PositiveIntegerField,
                                       models.PositiveSmallIntegerField)))):
            return models.IntegerField().db_type()
        return rel_field.db_type()

    # ForeignKey monkey-patch to support BigAutoId
    models.ForeignKey.db_type = fk_db_type



class PositiveBigIntegerField(BigIntegerField):
    # Note: Same internal type as BigIntegerField

    def formfield(self, **kwargs):
        defaults = {'min_value': 0}
        defaults.update(kwargs)
        return super(PositiveBigIntegerField, self).formfield(**defaults)

class PickledObjectField(models.TextField):
    __metaclass__ = models.SubfieldBase

    def __init__(self, *args, **kwargs):
        warnings.warn('PickledObjectField is deprecated. Use django-picklefield instead.')
        super(PickledObjectField, self).__init__(*args, **kwargs)
 
    def to_python(self, value):
        if value is None: 
            return None
        if not isinstance(value, basestring):
            return value
        return pickle.loads(base64.b64decode(value))
 
    def get_db_prep_save(self, value, connection=None):
        if value is None: 
            return
        return base64.b64encode(pickle.dumps(value))

class JSONField(models.TextField):
    __metaclass__ = models.SubfieldBase

    def __init__(self, *args, **kwargs):
        warnings.warn('JSONField is deprecated. Use django-jsonfield instead.')
        super(JSONField, self).__init__(*args, **kwargs)
 
    def formfield(self, **kwargs):
        defaults = {'widget': JSONWidget, 'form_class': JSONFormField}
        defaults.update(kwargs)
        return super(JSONField, self).formfield(**defaults)
 
    def to_python(self, value):
        # If value is a bastring but empty then pass
        if isinstance(value, basestring):
            if value == '':
                return None
            else:
                value = simplejson.loads(value)
        return value

    def get_db_prep_value(self, value, connection=None, prepared=None):
        if value is None: return
        return simplejson.dumps(value, cls=DjangoJSONEncoder)
 
    def value_to_string(self, obj):
        value = self._get_val_from_obj(obj)
        return self.get_db_prep_value(value)


try:
    from south.modelsinspector import add_introspection_rules

    add_introspection_rules([

        ((BigAutoField,), [], {},),

    ], [r"^beproud\.django\.commons\.models"])
except ImportError:
    pass



#:coding=utf-8:

from django.test import TestCase as DjangoTestCase
from django.core.exceptions import ValidationError
from django.db import connection
from django.db import models

from beproud.django.commons.models import (
    BaseModel,
    BigAutoField,
    BigIntegerField,
    JSONField,
)

class BigIDModel(BaseModel):
    id = BigAutoField(primary_key=True)

class TestBigIntModel(BaseModel):
    big_id_obj = models.ForeignKey(BigIDModel)
 
class SmallIDModel(BaseModel):
    pass

class TestBigToSmallModel(BaseModel):
    small_id_obj = models.ForeignKey(SmallIDModel)

class ManyToManyTestModel(BaseModel):
    bigids = models.ManyToManyField(BigIDModel)

class JSONFieldTestModel(models.Model):
    json = JSONField(u"test", null=True, blank=True)

class BigForeignKeyTest(DjangoTestCase):

    def test_simple(self):
        qs = TestBigIntModel.objects.recently_updated()

        # クエリがデータを返すかどうかをチェック
        self.assertTrue(qs)

        for obj in qs:
            self.assertTrue(obj.big_id_obj_id)
            self.assertTrue(obj.big_id_obj.id)

    def test_bigtosmall(self):
        qs = TestBigToSmallModel.objects.recently_updated()

        # クエリがデータを返すかどうかをチェック
        self.assertTrue(qs)

        for obj in qs:
            self.assertTrue(obj.small_id_obj_id)
            self.assertTrue(obj.small_id_obj.id)

    def test_bigforeignkey_db_type(self):
        qs = TestBigIntModel.objects.recently_updated()
        # クエリがデータを返すかどうかをチェック
        self.assertTrue(qs)
        for obj in qs:
            for f in obj._meta.fields:
                if f.name == "big_id_obj":
                    db_type = f.db_type(connection)
                    bigint_type = BigIntegerField().db_type(connection=connection)
                    self.assertEquals(db_type, bigint_type) # oracleでは動かない

        qs = TestBigToSmallModel.objects.recently_updated()
        # クエリがデータを返すかどうかをチェック
        self.assertTrue(qs)
        for obj in qs:
            for f in obj._meta.fields:
                if f.name == "small_id_obj":
                    db_type = f.db_type(connection)
                    int_type = models.IntegerField().db_type(connection=connection)
                    self.assertEquals(db_type, int_type) # oracleでは動かない

    def test_manytomany_db_type(self):
        for obj in ManyToManyTestModel.objects.all():
            bigids = obj.bigids.all()
            self.assertTrue(len(bigids) > 0)
            for bigid in bigids:
                self.assertTrue(bigid.id)

class BadBigAutoIdTest(DjangoTestCase):
    def test_bad_id(self):
        try:
            bad_id = BigIDModel._meta.pk.to_python("bad id")
            self.fail("Expected fail")
        except ValidationError:
            pass

class JSONFieldTest(DjangoTestCase):
    def test_json_field(self):
        obj = JSONFieldTestModel(json='''{
            "spam": "eggs"
        }''')
        self.assertEquals(obj.json, {'spam':'eggs'})

    def test_json_field_empty(self):
        obj = JSONFieldTestModel(json='')
        self.assertEquals(obj.json, None)

    def test_json_field_save(self):
        obj = JSONFieldTestModel.objects.create(
            id=10, 
            json='''{
                "spam": "eggs"
            }''',
        )
        obj2 = JSONFieldTestModel.objects.get(id=10)
        self.assertEquals(obj2.json, {'spam':'eggs'})

    def test_json_field_save_empty(self):
        obj = JSONFieldTestModel.objects.create(id=10, json='')
        obj2 = JSONFieldTestModel.objects.get(id=10)
        self.assertEquals(obj2.json, None)

    def test_db_prep_value(self):
        field = JSONField(u"test")
        field.set_attributes_from_name("json")
        self.assertEquals(None, field.get_db_prep_value(None))
        self.assertEquals('{"spam": "eggs"}', field.get_db_prep_value({"spam": "eggs"}))

    def test_value_to_string(self):
        field = JSONField(u"test")
        field.set_attributes_from_name("json")
        obj = JSONFieldTestModel(json='''{
            "spam": "eggs"
        }''')
        self.assertEquals('{"spam": "eggs"}', field.value_to_string(obj))

    def test_formfield(self):
        from beproud.django.commons.forms import JSONField as JSONFormField
        from beproud.django.commons.forms.widgets import JSONWidget
        field = JSONField(u"test")
        field.set_attributes_from_name("json")
        formfield = field.formfield()
        self.assertEquals(type(formfield), JSONFormField)
        self.assertEquals(type(formfield.widget), JSONWidget)




#:coding=utf-8:

__all__ = ['sort_form_field']

def sort_form_field(form_class, field_names):
    """
    フォームクラスのフィールドをソートする
    field_namesに与えたフィールドを優先する
    """
    def _key(c):
        return -len(field_names) + field_names.index(c) if c in field_names else 1
    form_class.base_fields.keyOrder.sort(key=_key)



from javascript_tests import *
from template_tests import *
from cache_tests import *
from views_tests import *
from templatetags_tests import *

from http import *
from shortcuts import *

from models.base.models import *
from models.fields.models import *

from forms.field_tests import *



#:coding=utf-8:
from django.conf.urls.defaults import *
from django.conf import settings

from beproud.django.commons.tests.views_tests import TestViews

urlpatterns = patterns('',
    (r'', include(TestViews().urls)),
    (r'json_response', 'beproud.django.commons.tests.http.test_json_response'),
)



#:coding=utf-8:

from django.test import TestCase as DjangoTestCase

from django.forms import Form

from beproud.django.commons.forms import EmailField, JSONField
from beproud.django.commons.forms.widgets import JSONWidget

__all__ = (
    'EmailFieldTest',
    'JSONFormFieldTest',
    'JSONWidgetTest',
)

class EmailTestForm(Form):
    email = EmailField(label="email")

class EmailFieldTest(DjangoTestCase):

    def test_basic_email(self):
        form = EmailTestForm({"email": "spam@eggs.com"})
        self.assertTrue(form.is_valid())

    def test_keitai_email(self):
        form = EmailTestForm({"email": "-spam..eggs-@softbank.ne.jp"})
        self.assertTrue(form.is_valid())

        form = EmailTestForm({"email": ".*&$.-spam..!!eggs!!-.*.@ezweb.ne.jp"})
        self.assertTrue(form.is_valid())

    def test_plus_email(self):
        form = EmailTestForm({"email": "spam+extra@eggs.com"})
        self.assertTrue(form.is_valid())
    
    def test_multi_email(self):
        form = EmailTestForm({"email": "aaa spam+extra@eggs.com email@email.com"})
        self.assertFalse(form.is_valid())

class JSONFormFieldTest(DjangoTestCase):

    def test_json(self):
        class JSONTestForm(Form):
            json = JSONField(label="json")

        form = JSONTestForm({"json": '{"spam": "eggs"}'})
        self.assertTrue(form.is_valid())
        self.assertEquals(form.cleaned_data["json"], {"spam": "eggs"})

    def test_json_fail(self):
        class JSONTestForm(Form):
            json = JSONField(label="json")

        form = JSONTestForm({"json": '{"spam": "eggs"'})
        self.assertFalse(form.is_valid())

    def test_to_python(self):
        class JSONTestForm(Form):
            json = JSONField(label="json")

        form = JSONTestForm({"json": {"spam": "eggs"}})
        self.assertTrue(form.is_valid())
        self.assertEquals(form.cleaned_data["json"], {"spam": "eggs"})

    def test_to_python_with_max_length(self):
        class JSONTestForm(Form):
            json = JSONField(label="json", max_length=100)

        form = JSONTestForm({"json": {"spam": "eggs"}})
        self.assertTrue(form.is_valid())
        self.assertEquals(form.cleaned_data["json"], {"spam": "eggs"})

    def test_to_python_with_max_length_fail(self):
        class JSONTestForm(Form):
            json = JSONField(label="json", max_length=5)

        form = JSONTestForm({"json": {"spam": "eggs"}})
        self.assertFalse(form.is_valid())

    def test_to_python_empty_values_required(self):
        class JSONTestForm(Form):
            json = JSONField(label="json", required=True)

        form = JSONTestForm({'json': '{}'})
        self.assertTrue(form.is_valid())
        self.assertEquals(form.cleaned_data["json"], {})

        form = JSONTestForm({'json': {}})
        self.assertTrue(form.is_valid())
        self.assertEquals(form.cleaned_data["json"], {})

        form = JSONTestForm({'json': ''})
        self.assertFalse(form.is_valid())
        self.assertTrue(form.errors.get('json'), form.fields['json'].error_messages['required'])

    def test_to_python_not_required(self):
        class JSONTestForm(Form):
            json = JSONField(label="json", required=False)

        form = JSONTestForm({'json': ''})
        self.assertTrue(form.is_valid())
        self.assertTrue(form.cleaned_data['json'] is None)

class JSONWidgetTest(DjangoTestCase):
    def test_jsonwidget(self):
        class JSONTestForm(Form):
            json = JSONField(label="json")

        form = JSONTestForm({"json": '{"spam": "eggs"}'})
        self.assertEquals(str(form), '<tr><th><label for="id_json">json:</label></th><td><textarea id="id_json" rows="10" cols="40" name="json">{&quot;spam&quot;: &quot;eggs&quot;}</textarea></td></tr>')

    def test_render(self):
        widget = JSONWidget()
        self.assertEquals(
            widget.render("json", {"spam": "eggs"}),
            '<textarea rows="10" cols="40" name="json">{\n  &quot;spam&quot;: &quot;eggs&quot;\n}</textarea>');




#:coding=utf-8:

from django.template import Library

from beproud.django.commons.utils.template import data_template_tag 
register = Library()

@register.tag
@data_template_tag
def get_my_data(num):
    if num == 121:
        return "MY DATA"
    else:
        return "ERROR"

@register.tag
@data_template_tag
def get_my_kwarg_data(num, status=None, other="other"):
    return "%s:%s:%s" % (num, status, other)



#!/usr/bin/env python
#:coding=utf-8:

from setuptools import setup, find_packages
 
setup (
    name='beproud.django.commons',
    version='0.3',
    description='Common utilities for Django',
    author='BeProud Inc.',
    author_email='ian@beproud.jp',
    url='http://www.beproud.jp/',
    classifiers=[
      'Development Status :: 3 - Alpha',
      'Environment :: Plugins',
      'Framework :: Django',
      'Intended Audience :: Developers',
      'License :: OSI Approved :: BSD License',
      'Programming Language :: Python',
      'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    include_package_data=True,
    packages=find_packages(),
    namespace_packages=['beproud', 'beproud.django'],
    install_requires=[
        'Django>=1.2',
        'zenhan>=0.4',
        # 'bputils>=0.31'
    ],
    test_suite='tests.main',
    zip_safe=False,
)



#:coding=utf-8:
import os

from django.test import TestCase as DjangoTestCase
from django.conf import settings

from django.template.loader import render_to_string

__all__ = (
    'StringTagsTestCase',
    'HtmlTagsTestCase',
    'SwitchTestCase',
)

class StringTagsTestCase(DjangoTestCase):

    def setUp(self):
        self.template_dirs = settings.TEMPLATE_DIRS

    def tearDown(self):
        settings.TEMPLATE_DIRS = self.template_dirs
 
    def test_abbrev(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        output = render_to_string("templatetags_tests/string_tags.html", {"my_data": "1234567890abcdefghi"})
        self.assertEquals(output, "<html><body>1234567...</body></html>\n") 

    def test_abbrev_filter_tag(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        output = render_to_string("templatetags_tests/string_tags2.html", {"my_data": "1234567890abcdefghi"})
        self.assertEquals(output, "<html><body>1234567...</body></html>\n") 

class HtmlTagsTestCase(DjangoTestCase):

    def setUp(self):
        self.template_dirs = settings.TEMPLATE_DIRS

    def tearDown(self):
        settings.TEMPLATE_DIRS = self.template_dirs
 
    def test_to_anchor(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        output = render_to_string("templatetags_tests/to_anchor.html", {
            "my_data": u"これはテストデータ。http://www.beproud.jp/これはテストデータ。",
        })
        self.assertEquals(output, u'<html><body>これはテストデータ。<a href="http://www.beproud.jp/" target="_blank" rel="nofollow">http://www.beproud.jp/</a>これはテストデータ。</body></html>\n')

    def test_to_anchortrunc(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        output = render_to_string("templatetags_tests/to_anchortrunc.html", {
            "my_data": u"これはテストデータ。http://www.beproud.jp/これはテストデータ。",
        })
        self.assertEquals(output, u'<html><body>これはテストデータ。<a href="http://www.beproud.jp/" target="_blank" rel="nofollow">http://www.b...</a>これはテストデータ。</body></html>\n')

class SwitchTestCase(DjangoTestCase):

    def setUp(self):
        self.template_dirs = settings.TEMPLATE_DIRS

    def tearDown(self):
        settings.TEMPLATE_DIRS = self.template_dirs

    def test_first(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        output = render_to_string("templatetags_tests/switch_test.html", {
            'value': 'first',
        })
        self.assertEquals(output, u'<html><body>first value</body></html>\n')

    def test_second(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        output = render_to_string("templatetags_tests/switch_test.html", {
            'value': 'second',
        })
        self.assertEquals(output, u'<html><body>second value</body></html>\n')

    def test_default(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        output = render_to_string("templatetags_tests/switch_test.html", {
            'value': 'not_exists',
        })
        self.assertEquals(output, u'<html><body>default</body></html>\n')

    def test_missing(self):
        settings.TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),)
        output = render_to_string("templatetags_tests/switch_test.html", {})
        self.assertEquals(output, u'<html><body>default</body></html>\n')



# vim:fileencoding=utf-8

def select(connection, sql, params=None, model=None):
    """
    SQLを実行してmodelに値を入れる
    connectionがPythonDBIに対応していれば利用可能
    """
    cur = connection.cursor()
    if params:
        cur.execute(sql, params)
    else:
        cur.execute(sql)
    columns = [column_info[0] for column_info in cur.description]
    raw_results = cur.fetchall()

    dict_results = []
    if not raw_results:
        return []
    for row in raw_results:
        dict_results.append(dict(zip(columns, row)))
    if model is None:
        return dict_results

    obj_results = []
    for item in dict_results:
        instance = model()
        for key, value in item.iteritems():
            setattr(instance, key, value)
        obj_results.append(instance)
    return obj_results



# vim:fileencoding=utf-8

from django.http import HttpResponse
from django.utils import simplejson

from beproud.django.commons.utils.javascript import DjangoJSONEncoder

__all__ = (
    'JSONResponse',
)

class JSONResponse(HttpResponse):
    """
    HttpResponse descendant, which return response with ``application/json`` mimetype.
    """
    def __init__(self, data={}, status=200, content_type='application/json'):
        super(JSONResponse, self).__init__(simplejson.dumps(data, cls=DjangoJSONEncoder), status=status, content_type=content_type)

